You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@wicket.apache.org by jc...@apache.org on 2007/04/10 20:16:39 UTC

svn commit: r527232 [13/28] - in /incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src: main/java/ main/java/org/ main/java/org/apache/ main/java/org/apache/wicket/ main/java/org/apache/wicket/ajax/ main/java/org/apache/wicket/ajax/calldecorator/ ma...

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/WebRequestCycle.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/WebRequestCycle.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/WebRequestCycle.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/WebRequestCycle.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/WebRequestCycle.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/WebRequestCycle.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/WebRequestCycle.java Tue Apr 10 11:15:14 2007
@@ -14,24 +14,24 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.protocol.http;
+package org.apache.wicket.protocol.http;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.AbortException;
+import org.apache.wicket.IRedirectListener;
+import org.apache.wicket.MetaDataKey;
+import org.apache.wicket.Page;
+import org.apache.wicket.RequestCycle;
+import org.apache.wicket.Response;
+import org.apache.wicket.RestartResponseAtInterceptPageException;
+import org.apache.wicket.Session;
+import org.apache.wicket.markup.html.pages.BrowserInfoPage;
+import org.apache.wicket.protocol.http.request.WebClientInfo;
+import org.apache.wicket.request.ClientInfo;
+import org.apache.wicket.request.IRequestCycleProcessor;
+import org.apache.wicket.settings.IRequestCycleSettings;
 
-import wicket.AbortException;
-import wicket.IRedirectListener;
-import wicket.MetaDataKey;
-import wicket.Page;
-import wicket.RequestCycle;
-import wicket.Response;
-import wicket.RestartResponseAtInterceptPageException;
-import wicket.Session;
-import wicket.markup.html.pages.BrowserInfoPage;
-import wicket.protocol.http.request.WebClientInfo;
-import wicket.request.ClientInfo;
-import wicket.request.IRequestCycleProcessor;
-import wicket.settings.IRequestCycleSettings;
 
 /**
  * RequestCycle implementation for HTTP protocol. Holds the application,
@@ -85,7 +85,7 @@
 	 * called unless you deliberately put effort in it to make it work.</strong>
 	 * </p>
 	 * 
-	 * @see wicket.RequestCycle#getProcessor()
+	 * @see org.apache.wicket.RequestCycle#getProcessor()
 	 */
 	public IRequestCycleProcessor getProcessor()
 	{
@@ -229,7 +229,7 @@
 	}
 
 	/**
-	 * @see wicket.RequestCycle#newClientInfo()
+	 * @see org.apache.wicket.RequestCycle#newClientInfo()
 	 */
 	protected ClientInfo newClientInfo()
 	{
@@ -255,7 +255,7 @@
 	/**
 	 * If it's an ajax request we always redirects.
 	 * 
-	 * @see wicket.RequestCycle#getRedirect()
+	 * @see org.apache.wicket.RequestCycle#getRedirect()
 	 */
 	public final boolean getRedirect()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/WebRequestCycleProcessor.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/WebRequestCycleProcessor.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/WebRequestCycleProcessor.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/WebRequestCycleProcessor.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/WebRequestCycleProcessor.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/WebRequestCycleProcessor.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/WebRequestCycleProcessor.java Tue Apr 10 11:15:14 2007
@@ -14,24 +14,24 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.protocol.http;
+package org.apache.wicket.protocol.http;
 
-import wicket.AccessStackPageMap;
-import wicket.Component;
-import wicket.IPageMap;
-import wicket.IRequestTarget;
-import wicket.Page;
-import wicket.PageParameters;
-import wicket.RequestCycle;
-import wicket.Session;
-import wicket.AccessStackPageMap.Access;
-import wicket.protocol.http.request.WebRequestCodingStrategy;
-import wicket.request.AbstractRequestCycleProcessor;
-import wicket.request.IRequestCodingStrategy;
-import wicket.request.RequestParameters;
-import wicket.request.target.component.BookmarkableListenerInterfaceRequestTarget;
-import wicket.request.target.component.IBookmarkablePageRequestTarget;
-import wicket.util.string.Strings;
+import org.apache.wicket.AccessStackPageMap;
+import org.apache.wicket.Component;
+import org.apache.wicket.IPageMap;
+import org.apache.wicket.IRequestTarget;
+import org.apache.wicket.Page;
+import org.apache.wicket.PageParameters;
+import org.apache.wicket.RequestCycle;
+import org.apache.wicket.Session;
+import org.apache.wicket.AccessStackPageMap.Access;
+import org.apache.wicket.protocol.http.request.WebRequestCodingStrategy;
+import org.apache.wicket.request.AbstractRequestCycleProcessor;
+import org.apache.wicket.request.IRequestCodingStrategy;
+import org.apache.wicket.request.RequestParameters;
+import org.apache.wicket.request.target.component.BookmarkableListenerInterfaceRequestTarget;
+import org.apache.wicket.request.target.component.IBookmarkablePageRequestTarget;
+import org.apache.wicket.util.string.Strings;
 
 /**
  * Default request processor implementation for normal web applications.
@@ -48,8 +48,8 @@
 	}
 
 	/**
-	 * @see wicket.request.IRequestCycleProcessor#resolve(wicket.RequestCycle,
-	 *      wicket.request.RequestParameters)
+	 * @see org.apache.wicket.request.IRequestCycleProcessor#resolve(org.apache.wicket.RequestCycle,
+	 *      org.apache.wicket.request.RequestParameters)
 	 */
 	public IRequestTarget resolve(final RequestCycle requestCycle,
 			final RequestParameters requestParameters)
@@ -186,13 +186,13 @@
 
 
 		// if we get here, we have no regconized Wicket target, and thus
-		// regard this as a external (non-wicket) resource request on
+		// regard this as a external (non-org.apache.wicket) resource request on
 		// this server
 		return resolveExternalResource(requestCycle);
 	}
 
 	/**
-	 * @see wicket.request.AbstractRequestCycleProcessor#newRequestCodingStrategy()
+	 * @see org.apache.wicket.request.AbstractRequestCycleProcessor#newRequestCodingStrategy()
 	 */
 	protected IRequestCodingStrategy newRequestCodingStrategy()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/WebRequestWithCryptedUrl.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/WebRequestWithCryptedUrl.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/WebRequestWithCryptedUrl.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/WebRequestWithCryptedUrl.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/WebRequestWithCryptedUrl.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/WebRequestWithCryptedUrl.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/WebRequestWithCryptedUrl.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.protocol.http;
+package org.apache.wicket.protocol.http;
 
 import java.io.UnsupportedEncodingException;
 import java.net.URLDecoder;
@@ -25,14 +25,15 @@
 
 import javax.servlet.http.HttpServletRequest;
 
-import wicket.Application;
-import wicket.PageParameters;
-import wicket.WicketRuntimeException;
-import wicket.protocol.http.request.WebRequestCodingStrategy;
-import wicket.protocol.http.servlet.ServletWebRequest;
-import wicket.util.crypt.ICrypt;
-import wicket.util.string.Strings;
-import wicket.util.value.ValueMap;
+import org.apache.wicket.Application;
+import org.apache.wicket.PageParameters;
+import org.apache.wicket.WicketRuntimeException;
+import org.apache.wicket.protocol.http.request.WebRequestCodingStrategy;
+import org.apache.wicket.protocol.http.servlet.ServletWebRequest;
+import org.apache.wicket.util.crypt.ICrypt;
+import org.apache.wicket.util.string.Strings;
+import org.apache.wicket.util.value.ValueMap;
+
 
 /**
  * It extends WebRequest and decodes URLs encoded by WebResponseWithCryptedUrl.
@@ -41,7 +42,7 @@
  * 
  * @author Juergen Donnerstag
  * 
- * @deprecated since 1.2 Please see {@link wicket.protocol.http.request.CryptedUrlwebRequestCodingStrategy}
+ * @deprecated since 1.2 Please see {@link org.apache.wicket.protocol.http.request.CryptedUrlwebRequestCodingStrategy}
  */
 public class WebRequestWithCryptedUrl extends ServletWebRequest
 {
@@ -109,7 +110,7 @@
 	}
 
 	/**
-	 * @see wicket.Request#decodeURL(java.lang.String)
+	 * @see org.apache.wicket.Request#decodeURL(java.lang.String)
 	 */
 	public String decodeURL(final String url)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/WebResponse.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/WebResponse.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/WebResponse.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/WebResponse.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/WebResponse.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/WebResponse.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/WebResponse.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.protocol.http;
+package org.apache.wicket.protocol.http;
 
 import java.io.IOException;
 import java.io.OutputStream;
@@ -25,12 +25,12 @@
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.Response;
+import org.apache.wicket.WicketRuntimeException;
+import org.apache.wicket.util.string.AppendingStringBuffer;
+import org.apache.wicket.util.string.Strings;
+import org.apache.wicket.util.time.Time;
 
-import wicket.Response;
-import wicket.WicketRuntimeException;
-import wicket.util.string.AppendingStringBuffer;
-import wicket.util.string.Strings;
-import wicket.util.time.Time;
 
 /**
  * Implements responses over the HTTP protocol by holding an underlying
@@ -135,7 +135,7 @@
 	}
 
 	/**
-	 * @see wicket.Response#getOutputStream()
+	 * @see org.apache.wicket.Response#getOutputStream()
 	 */
 	public OutputStream getOutputStream()
 	{
@@ -194,7 +194,7 @@
 					{
 						/*
 						 * By reaching this point, make sure the HTTP response
-						 * status code is set to 200, otherwise wicket-ajax.js
+						 * status code is set to 200, otherwise org.apache.wicket-ajax.js
 						 * will not process the Ajax-Location header
 						 */
 						httpServletResponse.addHeader("Ajax-Location", url);
@@ -233,7 +233,7 @@
 	}
 
 	/**
-	 * @see wicket.Response#setContentLength(long)
+	 * @see org.apache.wicket.Response#setContentLength(long)
 	 */
 	public void setContentLength(long length)
 	{
@@ -241,7 +241,7 @@
 	}
 
 	/**
-	 * @see wicket.Response#setLastModifiedTime(wicket.util.time.Time)
+	 * @see org.apache.wicket.Response#setLastModifiedTime(org.apache.wicket.util.time.Time)
 	 */
 	public void setLastModifiedTime(Time time)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/WebResponseWithCryptedUrl.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/WebResponseWithCryptedUrl.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/WebResponseWithCryptedUrl.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/WebResponseWithCryptedUrl.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/WebResponseWithCryptedUrl.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/WebResponseWithCryptedUrl.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/WebResponseWithCryptedUrl.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.protocol.http;
+package org.apache.wicket.protocol.http;
 
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
@@ -23,20 +23,20 @@
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.Application;
+import org.apache.wicket.protocol.http.request.WebRequestCodingStrategy;
+import org.apache.wicket.util.crypt.ICrypt;
+import org.apache.wicket.util.string.AppendingStringBuffer;
+import org.apache.wicket.util.string.Strings;
 
-import wicket.Application;
-import wicket.protocol.http.request.WebRequestCodingStrategy;
-import wicket.util.crypt.ICrypt;
-import wicket.util.string.AppendingStringBuffer;
-import wicket.util.string.Strings;
 
 /**
- * It extends WebResponse and encodes (encrypt) wicket's URL 
+ * It extends WebResponse and encodes (encrypt) org.apache.wicket's URL 
  * query string. Thus it hides the details from the user.
  *  
  * @author Juergen Donnerstag
  * 
- * @deprecated since 1.2 Please see {@link wicket.protocol.http.request.CryptedUrlwebRequestCodingStrategy}
+ * @deprecated since 1.2 Please see {@link org.apache.wicket.protocol.http.request.CryptedUrlwebRequestCodingStrategy}
  */
 public class WebResponseWithCryptedUrl extends WebResponse
 {

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/WebSession.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/WebSession.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/WebSession.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/WebSession.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/WebSession.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/WebSession.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/WebSession.java Tue Apr 10 11:15:14 2007
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.protocol.http;
+package org.apache.wicket.protocol.http;
 
-import wicket.Application;
-import wicket.IRequestCycleFactory;
-import wicket.Request;
-import wicket.RequestCycle;
-import wicket.Session;
+import org.apache.wicket.Application;
+import org.apache.wicket.IRequestCycleFactory;
+import org.apache.wicket.Request;
+import org.apache.wicket.RequestCycle;
+import org.apache.wicket.Session;
 
 /**
  * A session subclass for the HTTP protocol.
@@ -125,7 +125,7 @@
 	 * Called on the end of handling a request, when the RequestCycle is about
 	 * to be detached from the current thread.
 	 * 
-	 * @see wicket.Session#detach()
+	 * @see org.apache.wicket.Session#detach()
 	 */
 	protected void detach()
 	{
@@ -136,7 +136,7 @@
 	}
 
 	/**
-	 * @see wicket.Session#getRequestCycleFactory()
+	 * @see org.apache.wicket.Session#getRequestCycleFactory()
 	 */
 	protected IRequestCycleFactory getRequestCycleFactory()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/WicketFilter.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/WicketFilter.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/WicketFilter.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/WicketFilter.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/WicketFilter.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/WicketFilter.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/WicketFilter.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.protocol.http;
+package org.apache.wicket.protocol.http;
 
 import java.io.IOException;
 import java.io.InputStream;
@@ -32,21 +32,21 @@
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.AbortException;
+import org.apache.wicket.Application;
+import org.apache.wicket.RequestCycle;
+import org.apache.wicket.Resource;
+import org.apache.wicket.Session;
+import org.apache.wicket.WicketRuntimeException;
+import org.apache.wicket.markup.parser.XmlPullParser;
+import org.apache.wicket.markup.parser.XmlTag;
+import org.apache.wicket.protocol.http.request.WebRequestCodingStrategy;
+import org.apache.wicket.session.ISessionStore;
+import org.apache.wicket.settings.IRequestCycleSettings;
+import org.apache.wicket.util.resource.IResourceStream;
+import org.apache.wicket.util.string.Strings;
+import org.apache.wicket.util.time.Time;
 
-import wicket.AbortException;
-import wicket.Application;
-import wicket.RequestCycle;
-import wicket.Resource;
-import wicket.Session;
-import wicket.WicketRuntimeException;
-import wicket.markup.parser.XmlPullParser;
-import wicket.markup.parser.XmlTag;
-import wicket.protocol.http.request.WebRequestCodingStrategy;
-import wicket.session.ISessionStore;
-import wicket.settings.IRequestCycleSettings;
-import wicket.util.resource.IResourceStream;
-import wicket.util.string.Strings;
-import wicket.util.time.Time;
 
 /**
  * Filter for initiating handling of Wicket requests.
@@ -82,7 +82,7 @@
 
 	/**
 	 * This is the filter path that can be specified in the filter config. Or it
-	 * is the servlet path if the wicket servlet it used. both are without any /
+	 * is the servlet path if the org.apache.wicket servlet it used. both are without any /
 	 * (start or end)
 	 */
 	private String filterPath;
@@ -175,7 +175,7 @@
 
 			// If the request does not provide information about the encoding of
 			// its body (which includes POST parameters), than assume the
-			// default encoding as defined by the wicket application. Bear in
+			// default encoding as defined by the org.apache.wicket application. Bear in
 			// mind that the encoding of the request usually is equal to the
 			// previous response.
 			// However it is a known bug of IE that it does not provide this
@@ -185,7 +185,7 @@
 			{
 				try
 				{
-					// The encoding defined by the wicket settings is used to
+					// The encoding defined by the org.apache.wicket settings is used to
 					// encode the responses. Thus, it is reasonable to assume
 					// the request has the same encoding. This is especially
 					// important for forms and form parameters.
@@ -230,7 +230,7 @@
 			Application.set(webApplication);
 
 			// Create a response object and set the output encoding according to
-			// wicket's application setttings.
+			// org.apache.wicket's application setttings.
 			final WebResponse response = webApplication.newWebResponse(servletResponse);
 			response.setAjax(request.isAjax());
 			response.setCharacterEncoding(webApplication.getRequestCycleSettings()
@@ -379,7 +379,7 @@
 
 			// Store instance of this application object in servlet context to
 			// make integration with outside world easier
-			String contextKey = "wicket:" + filterConfig.getFilterName();
+			String contextKey = "org.apache.wicket:" + filterConfig.getFilterName();
 			filterConfig.getServletContext().setAttribute(contextKey, this.webApplication);
 
 			Application.set(webApplication);

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/WicketServlet.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/WicketServlet.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/WicketServlet.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/WicketServlet.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/WicketServlet.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/WicketServlet.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/WicketServlet.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.protocol.http;
+package org.apache.wicket.protocol.http;
 
 import java.io.IOException;
 import java.util.Enumeration;
@@ -33,7 +33,7 @@
  * 
  * Please use {@link WicketFilter} if you require advanced chaining of resources.
  * 
- * Servlet class for all wicket applications. The specific application class to
+ * Servlet class for all org.apache.wicket applications. The specific application class to
  * instantiate should be specified to the application server via an init-params
  * argument named "applicationClassName" in the servlet declaration, which is
  * typically in a <i>web.xml </i> file. The servlet declaration may vary from
@@ -42,7 +42,7 @@
  * <pre>
  * &lt;servlet&gt;
  *   &lt;servlet-name&gt;MyApplication&lt;/servlet-name&gt;
- *   &lt;servlet-class&gt;wicket.protocol.http.WicketServlet&lt;/servlet-class&gt;
+ *   &lt;servlet-class&gt;org.apache.wicket.protocol.http.WicketServlet&lt;/servlet-class&gt;
  *   &lt;init-param&gt;
  *     &lt;param-name&gt;applicationClassName&lt;/param-name&gt;
  *     &lt;param-value&gt;com.whoever.MyApplication&lt;/param-value&gt;
@@ -67,12 +67,12 @@
  * </pre>
  * 
  * and it has to satisfy interface
- * {@link wicket.protocol.http.IWebApplicationFactory}.
+ * {@link org.apache.wicket.protocol.http.IWebApplicationFactory}.
  * 
  * <p>
  * When GET/POST requests are made via HTTP, a WebRequestCycle object is
  * created from the request, response and session objects (after wrapping them
- * in the appropriate wicket wrappers). The RequestCycle's render() method is
+ * in the appropriate org.apache.wicket wrappers). The RequestCycle's render() method is
  * then called to produce a response to the HTTP request.
  * <p>
  * If you want to use servlet specific configuration, e.g. using init parameters
@@ -92,7 +92,7 @@
  * variable webApplication is protected instead of private. Thus subclasses may
  * provide their own means of providing the application object.
  * 
- * @see wicket.RequestCycle
+ * @see org.apache.wicket.RequestCycle
  * @author Jonathan Locke
  * @author Timur Mehrvarz
  * @author Juergen Donnerstag
@@ -191,7 +191,7 @@
 	}
 
 	/**
-	 * @return The wicket filter 
+	 * @return The org.apache.wicket filter 
 	 */
 	protected WicketFilter newWicketFilter()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/documentvalidation/Comment.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/documentvalidation/Comment.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/documentvalidation/Comment.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/documentvalidation/Comment.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/documentvalidation/Comment.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/documentvalidation/Comment.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/documentvalidation/Comment.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.protocol.http.documentvalidation;
+package org.apache.wicket.protocol.http.documentvalidation;
 
 /**
  * Class representing a comment in an HTML document.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/documentvalidation/DocumentElement.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/documentvalidation/DocumentElement.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/documentvalidation/DocumentElement.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/documentvalidation/DocumentElement.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/documentvalidation/DocumentElement.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/documentvalidation/DocumentElement.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/documentvalidation/DocumentElement.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.protocol.http.documentvalidation;
+package org.apache.wicket.protocol.http.documentvalidation;
 
 /**
  * Marker interface indicating a document element.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/documentvalidation/HtmlDocumentParser.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/documentvalidation/HtmlDocumentParser.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/documentvalidation/HtmlDocumentParser.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/documentvalidation/HtmlDocumentParser.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/documentvalidation/HtmlDocumentParser.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/documentvalidation/HtmlDocumentParser.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/documentvalidation/HtmlDocumentParser.java Tue Apr 10 11:15:14 2007
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.protocol.http.documentvalidation;
+package org.apache.wicket.protocol.http.documentvalidation;
 
 import java.util.HashMap;
 import java.util.Map;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.util.string.Strings;
 
-import wicket.util.string.Strings;
 
 /**
  * Lightweight document parser for HTML. This parser is only intended to process

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/documentvalidation/HtmlDocumentValidator.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/documentvalidation/HtmlDocumentValidator.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/documentvalidation/HtmlDocumentValidator.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/documentvalidation/HtmlDocumentValidator.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/documentvalidation/HtmlDocumentValidator.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/documentvalidation/HtmlDocumentValidator.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/documentvalidation/HtmlDocumentValidator.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.protocol.http.documentvalidation;
+package org.apache.wicket.protocol.http.documentvalidation;
 
 import java.util.ArrayList;
 import java.util.Iterator;
@@ -23,8 +23,8 @@
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.util.collections.ArrayListStack;
 
-import wicket.util.collections.ArrayListStack;
 
 /**
  * Simple class that provides a convenient programmatic way to define what an

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/documentvalidation/Tag.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/documentvalidation/Tag.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/documentvalidation/Tag.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/documentvalidation/Tag.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/documentvalidation/Tag.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/documentvalidation/Tag.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/documentvalidation/Tag.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.protocol.http.documentvalidation;
+package org.apache.wicket.protocol.http.documentvalidation;
 
 import java.util.ArrayList;
 import java.util.HashMap;

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/documentvalidation/TextContent.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/documentvalidation/TextContent.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/documentvalidation/TextContent.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/documentvalidation/TextContent.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/documentvalidation/TextContent.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/documentvalidation/TextContent.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/documentvalidation/TextContent.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.protocol.http.documentvalidation;
+package org.apache.wicket.protocol.http.documentvalidation;
 
 /**
  * Class representing text content that can appear within an element.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/request/CryptedUrlWebRequestCodingStrategy.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/request/CryptedUrlWebRequestCodingStrategy.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/request/CryptedUrlWebRequestCodingStrategy.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/request/CryptedUrlWebRequestCodingStrategy.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/request/CryptedUrlWebRequestCodingStrategy.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/request/CryptedUrlWebRequestCodingStrategy.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/request/CryptedUrlWebRequestCodingStrategy.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.protocol.http.request;
+package org.apache.wicket.protocol.http.request;
 
 import java.io.UnsupportedEncodingException;
 import java.net.URLDecoder;
@@ -26,20 +26,20 @@
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.Application;
+import org.apache.wicket.IRequestTarget;
+import org.apache.wicket.Request;
+import org.apache.wicket.RequestCycle;
+import org.apache.wicket.WicketRuntimeException;
+import org.apache.wicket.protocol.http.RequestUtils;
+import org.apache.wicket.request.IRequestCodingStrategy;
+import org.apache.wicket.request.RequestParameters;
+import org.apache.wicket.request.target.coding.IRequestTargetUrlCodingStrategy;
+import org.apache.wicket.util.crypt.ICrypt;
+import org.apache.wicket.util.string.AppendingStringBuffer;
+import org.apache.wicket.util.string.Strings;
+import org.apache.wicket.util.value.ValueMap;
 
-import wicket.Application;
-import wicket.IRequestTarget;
-import wicket.Request;
-import wicket.RequestCycle;
-import wicket.WicketRuntimeException;
-import wicket.protocol.http.RequestUtils;
-import wicket.request.IRequestCodingStrategy;
-import wicket.request.RequestParameters;
-import wicket.request.target.coding.IRequestTargetUrlCodingStrategy;
-import wicket.util.crypt.ICrypt;
-import wicket.util.string.AppendingStringBuffer;
-import wicket.util.string.Strings;
-import wicket.util.value.ValueMap;
 
 /**
  * This is a request coding strategy which encrypts the URL and hence makes it
@@ -92,7 +92,7 @@
 	/**
 	 * Decode the querystring of the URL
 	 * 
-	 * @see wicket.request.IRequestCodingStrategy#decode(wicket.Request)
+	 * @see org.apache.wicket.request.IRequestCodingStrategy#decode(org.apache.wicket.Request)
 	 */
 	public RequestParameters decode(final Request request)
 	{
@@ -113,8 +113,8 @@
 	/**
 	 * Encode the querystring of the URL
 	 * 
-	 * @see wicket.request.IRequestCodingStrategy#encode(wicket.RequestCycle,
-	 *      wicket.IRequestTarget)
+	 * @see org.apache.wicket.request.IRequestCodingStrategy#encode(org.apache.wicket.RequestCycle,
+	 *      org.apache.wicket.IRequestTarget)
 	 */
 	public CharSequence encode(final RequestCycle requestCycle, final IRequestTarget requestTarget)
 	{
@@ -124,8 +124,8 @@
 	}
 
 	/**
-	 * @see wicket.request.IRequestTargetMounter#mount(java.lang.String,
-	 *      wicket.request.target.coding.IRequestTargetUrlCodingStrategy)
+	 * @see org.apache.wicket.request.IRequestTargetMounter#mount(java.lang.String,
+	 *      org.apache.wicket.request.target.coding.IRequestTargetUrlCodingStrategy)
 	 */
 	public void mount(String path, IRequestTargetUrlCodingStrategy urlCodingStrategy)
 	{
@@ -133,7 +133,7 @@
 	}
 
 	/**
-	 * @see wicket.request.IRequestTargetMounter#unmount(java.lang.String)
+	 * @see org.apache.wicket.request.IRequestTargetMounter#unmount(java.lang.String)
 	 */
 	public void unmount(String path)
 	{
@@ -141,7 +141,7 @@
 	}
 
 	/**
-	 * @see wicket.request.IRequestTargetMounter#urlCodingStrategyForPath(java.lang.String)
+	 * @see org.apache.wicket.request.IRequestTargetMounter#urlCodingStrategyForPath(java.lang.String)
 	 */
 	public IRequestTargetUrlCodingStrategy urlCodingStrategyForPath(String path)
 	{
@@ -149,7 +149,7 @@
 	}
 
 	/**
-	 * @see wicket.request.IRequestTargetMounter#pathForTarget(wicket.IRequestTarget)
+	 * @see org.apache.wicket.request.IRequestTargetMounter#pathForTarget(org.apache.wicket.IRequestTarget)
 	 */
 	public CharSequence pathForTarget(IRequestTarget requestTarget)
 	{
@@ -157,7 +157,7 @@
 	}
 
 	/**
-	 * @see wicket.request.IRequestTargetMounter#targetForRequest(wicket.request.RequestParameters)
+	 * @see org.apache.wicket.request.IRequestTargetMounter#targetForRequest(org.apache.wicket.request.RequestParameters)
 	 */
 	public IRequestTarget targetForRequest(RequestParameters requestParameters)
 	{
@@ -436,7 +436,7 @@
 		/**
 		 * Delegate to the original request
 		 * 
-		 * @see wicket.Request#getLocale()
+		 * @see org.apache.wicket.Request#getLocale()
 		 */
 		public Locale getLocale()
 		{
@@ -444,7 +444,7 @@
 		}
 
 		/**
-		 * @see wicket.Request#getParameter(java.lang.String)
+		 * @see org.apache.wicket.Request#getParameter(java.lang.String)
 		 */
 		public String getParameter(final String key)
 		{
@@ -456,7 +456,7 @@
 		}
 
 		/**
-		 * @see wicket.Request#getParameterMap()
+		 * @see org.apache.wicket.Request#getParameterMap()
 		 */
 		public Map getParameterMap()
 		{
@@ -464,7 +464,7 @@
 		}
 
 		/**
-		 * @see wicket.Request#getParameters(java.lang.String)
+		 * @see org.apache.wicket.Request#getParameters(java.lang.String)
 		 */
 		public String[] getParameters(final String key)
 		{
@@ -476,7 +476,7 @@
 		}
 
 		/**
-		 * @see wicket.Request#getPath()
+		 * @see org.apache.wicket.Request#getPath()
 		 */
 		public String getPath()
 		{
@@ -485,7 +485,7 @@
 		}
 
 		/**
-		 * @see wicket.Request#getRelativeURL()
+		 * @see org.apache.wicket.Request#getRelativeURL()
 		 */
 		public String getRelativeURL()
 		{
@@ -493,7 +493,7 @@
 		}
 
 		/**
-		 * @see wicket.Request#getURL()
+		 * @see org.apache.wicket.Request#getURL()
 		 */
 		public String getURL()
 		{
@@ -519,7 +519,7 @@
 		}
 
 		/**
-		 * No stack trace. We don't won't to tell the hacker internals of wicket
+		 * No stack trace. We don't won't to tell the hacker internals of org.apache.wicket
 		 * 
 		 * @see java.lang.Throwable#getStackTrace()
 		 */
@@ -530,7 +530,7 @@
 
 		/**
 		 * No additional information. We don't won't to tell the hacker
-		 * internals of wicket
+		 * internals of org.apache.wicket
 		 * 
 		 * @see java.lang.Throwable#toString()
 		 */

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/request/WebClientInfo.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/request/WebClientInfo.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/request/WebClientInfo.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/request/WebClientInfo.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/request/WebClientInfo.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/request/WebClientInfo.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/request/WebClientInfo.java Tue Apr 10 11:15:14 2007
@@ -14,17 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.protocol.http.request;
+package org.apache.wicket.protocol.http.request;
 
 import javax.servlet.http.HttpServletRequest;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.WicketRuntimeException;
+import org.apache.wicket.protocol.http.ClientProperties;
+import org.apache.wicket.protocol.http.WebRequestCycle;
+import org.apache.wicket.request.ClientInfo;
 
-import wicket.WicketRuntimeException;
-import wicket.protocol.http.ClientProperties;
-import wicket.protocol.http.WebRequestCycle;
-import wicket.request.ClientInfo;
 
 /**
  * Default client info object for web applications.
@@ -42,7 +42,7 @@
 	 * The user agent string from the User-Agent header, app. Theoretically,
 	 * this might differ from {@link ClientProperties#isJavaEnabled()} property,
 	 * which is not set until an actual reply from a browser (e.g. using
-	 * {@link wicket.markup.html.pages.BrowserInfoPage} is set.
+	 * {@link org.apache.wicket.markup.html.pages.BrowserInfoPage} is set.
 	 */
 	private final String userAgent;
 

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/request/WebErrorCodeResponseTarget.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/request/WebErrorCodeResponseTarget.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/request/WebErrorCodeResponseTarget.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/request/WebErrorCodeResponseTarget.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/request/WebErrorCodeResponseTarget.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/request/WebErrorCodeResponseTarget.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/request/WebErrorCodeResponseTarget.java Tue Apr 10 11:15:14 2007
@@ -14,22 +14,23 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.protocol.http.request;
+package org.apache.wicket.protocol.http.request;
 
 import java.io.IOException;
 
 import javax.servlet.http.HttpServletResponse;
 
-import wicket.IRequestTarget;
-import wicket.RequestCycle;
-import wicket.WicketRuntimeException;
-import wicket.protocol.http.WebRequestCycle;
-import wicket.protocol.http.WebResponse;
+import org.apache.wicket.IRequestTarget;
+import org.apache.wicket.RequestCycle;
+import org.apache.wicket.WicketRuntimeException;
+import org.apache.wicket.protocol.http.WebRequestCycle;
+import org.apache.wicket.protocol.http.WebResponse;
+
 
 /**
  * Response target that is to be used in a servlet environment to send an error
  * code and optionally a message. NOTE: this target can only be used in a
- * servlet environment with {@link wicket.protocol.http.WebRequestCycle}s.
+ * servlet environment with {@link org.apache.wicket.protocol.http.WebRequestCycle}s.
  * 
  * @author Eelco Hillenius
  */
@@ -74,7 +75,7 @@
 	 * Respond by sending the set errorCode and optionally the message to the
 	 * browser.
 	 * 
-	 * @see wicket.IRequestTarget#respond(wicket.RequestCycle)
+	 * @see org.apache.wicket.IRequestTarget#respond(org.apache.wicket.RequestCycle)
 	 */
 	public void respond(RequestCycle requestCycle)
 	{
@@ -118,7 +119,7 @@
 	}
 
 	/**
-	 * @see wicket.IRequestTarget#detach(wicket.RequestCycle)
+	 * @see org.apache.wicket.IRequestTarget#detach(org.apache.wicket.RequestCycle)
 	 */
 	public void detach(RequestCycle requestCycle)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/request/WebExternalResourceRequestTarget.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/request/WebExternalResourceRequestTarget.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/request/WebExternalResourceRequestTarget.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/request/WebExternalResourceRequestTarget.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/request/WebExternalResourceRequestTarget.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/request/WebExternalResourceRequestTarget.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/request/WebExternalResourceRequestTarget.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.protocol.http.request;
+package org.apache.wicket.protocol.http.request;
 
 import java.io.IOException;
 import java.io.InputStream;
@@ -24,19 +24,19 @@
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.IRequestTarget;
+import org.apache.wicket.RequestCycle;
+import org.apache.wicket.WicketRuntimeException;
+import org.apache.wicket.protocol.http.WebApplication;
+import org.apache.wicket.protocol.http.WebRequestCycle;
+import org.apache.wicket.protocol.http.WebResponse;
 
-import wicket.IRequestTarget;
-import wicket.RequestCycle;
-import wicket.WicketRuntimeException;
-import wicket.protocol.http.WebApplication;
-import wicket.protocol.http.WebRequestCycle;
-import wicket.protocol.http.WebResponse;
 
 /**
  * Request target that is not a Wicket resource. For example, such a resource
  * could denote an image in the web application directory (not mapped to a
  * Wicket servlet). NOTE: this target can only be used in a servlet environment
- * with {@link wicket.protocol.http.WebRequestCycle}s.
+ * with {@link org.apache.wicket.protocol.http.WebRequestCycle}s.
  * 
  * @author Eelco Hillenius
  */
@@ -70,7 +70,7 @@
 	 * resource is not found, a warning will be logged, and a 404 will be
 	 * issued.
 	 * 
-	 * @see wicket.IRequestTarget#respond(wicket.RequestCycle)
+	 * @see org.apache.wicket.IRequestTarget#respond(org.apache.wicket.RequestCycle)
 	 */
 	public void respond(RequestCycle requestCycle)
 	{
@@ -115,7 +115,7 @@
 	}
 
 	/**
-	 * @see wicket.IRequestTarget#detach(wicket.RequestCycle)
+	 * @see org.apache.wicket.IRequestTarget#detach(org.apache.wicket.RequestCycle)
 	 */
 	public void detach(RequestCycle requestCycle)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/request/WebRequestCodingStrategy.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/request/WebRequestCodingStrategy.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/request/WebRequestCodingStrategy.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/request/WebRequestCodingStrategy.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/request/WebRequestCodingStrategy.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/request/WebRequestCodingStrategy.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/request/WebRequestCodingStrategy.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.protocol.http.request;
+package org.apache.wicket.protocol.http.request;
 
 import java.io.UnsupportedEncodingException;
 import java.net.URLEncoder;
@@ -29,34 +29,34 @@
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.Application;
+import org.apache.wicket.Component;
+import org.apache.wicket.IPageMap;
+import org.apache.wicket.IRedirectListener;
+import org.apache.wicket.IRequestTarget;
+import org.apache.wicket.Page;
+import org.apache.wicket.PageMap;
+import org.apache.wicket.PageParameters;
+import org.apache.wicket.Request;
+import org.apache.wicket.RequestCycle;
+import org.apache.wicket.RequestListenerInterface;
+import org.apache.wicket.Session;
+import org.apache.wicket.WicketRuntimeException;
+import org.apache.wicket.protocol.http.WebRequest;
+import org.apache.wicket.request.IRequestCodingStrategy;
+import org.apache.wicket.request.IRequestTargetMountsInfo;
+import org.apache.wicket.request.RequestParameters;
+import org.apache.wicket.request.target.coding.IRequestTargetUrlCodingStrategy;
+import org.apache.wicket.request.target.component.BookmarkableListenerInterfaceRequestTarget;
+import org.apache.wicket.request.target.component.BookmarkablePageRequestTarget;
+import org.apache.wicket.request.target.component.IBookmarkablePageRequestTarget;
+import org.apache.wicket.request.target.component.IPageRequestTarget;
+import org.apache.wicket.request.target.component.listener.IListenerInterfaceRequestTarget;
+import org.apache.wicket.request.target.resource.ISharedResourceRequestTarget;
+import org.apache.wicket.util.string.AppendingStringBuffer;
+import org.apache.wicket.util.string.PrependingStringBuffer;
+import org.apache.wicket.util.string.Strings;
 
-import wicket.Application;
-import wicket.Component;
-import wicket.IPageMap;
-import wicket.IRedirectListener;
-import wicket.IRequestTarget;
-import wicket.Page;
-import wicket.PageMap;
-import wicket.PageParameters;
-import wicket.Request;
-import wicket.RequestCycle;
-import wicket.RequestListenerInterface;
-import wicket.Session;
-import wicket.WicketRuntimeException;
-import wicket.protocol.http.WebRequest;
-import wicket.request.IRequestCodingStrategy;
-import wicket.request.IRequestTargetMountsInfo;
-import wicket.request.RequestParameters;
-import wicket.request.target.coding.IRequestTargetUrlCodingStrategy;
-import wicket.request.target.component.BookmarkableListenerInterfaceRequestTarget;
-import wicket.request.target.component.BookmarkablePageRequestTarget;
-import wicket.request.target.component.IBookmarkablePageRequestTarget;
-import wicket.request.target.component.IPageRequestTarget;
-import wicket.request.target.component.listener.IListenerInterfaceRequestTarget;
-import wicket.request.target.resource.ISharedResourceRequestTarget;
-import wicket.util.string.AppendingStringBuffer;
-import wicket.util.string.PrependingStringBuffer;
-import wicket.util.string.Strings;
 
 /**
  * Request parameters factory implementation that uses http request parameters
@@ -186,7 +186,7 @@
 
 
 	/**
-	 * @see wicket.request.IRequestCodingStrategy#decode(wicket.Request)
+	 * @see org.apache.wicket.request.IRequestCodingStrategy#decode(org.apache.wicket.Request)
 	 */
 	public final RequestParameters decode(final Request request)
 	{
@@ -226,8 +226,8 @@
 	 * either, and exception will be thrown saying that encoding could not be
 	 * done.
 	 * 
-	 * @see wicket.request.IRequestCodingStrategy#encode(wicket.RequestCycle,
-	 *      wicket.IRequestTarget)
+	 * @see org.apache.wicket.request.IRequestCodingStrategy#encode(org.apache.wicket.RequestCycle,
+	 *      org.apache.wicket.IRequestTarget)
 	 */
 	public final CharSequence encode(final RequestCycle requestCycle,
 			final IRequestTarget requestTarget)
@@ -335,7 +335,7 @@
 			else if (url.length() > 0 && url.charAt(0) == '?')
 			{
 				// Keep the last part of mounted pages for resource/interface links.
-				// E.g. if we generate app/Clients we want links like "Clients?wicket:interface[...]"
+				// E.g. if we generate app/Clients we want links like "Clients?org.apache.wicket:interface[...]"
 				prepender.prepend(relativeUrl.substring(relativeUrl.lastIndexOf("/") + 1));
 			}
 			// Fix for the special case where we're linking to the home page; make the link "./" not "".
@@ -352,7 +352,7 @@
 	}
 
 	/**
-	 * @see wicket.request.IRequestTargetMountsInfo#listMounts()
+	 * @see org.apache.wicket.request.IRequestTargetMountsInfo#listMounts()
 	 */
 	public IRequestTargetUrlCodingStrategy[] listMounts()
 	{
@@ -361,7 +361,7 @@
 	}
 
 	/**
-	 * @see wicket.request.IRequestTargetMounter#urlCodingStrategyForPath(java.lang.String)
+	 * @see org.apache.wicket.request.IRequestTargetMounter#urlCodingStrategyForPath(java.lang.String)
 	 */
 	public final IRequestTargetUrlCodingStrategy urlCodingStrategyForPath(String path)
 	{
@@ -381,8 +381,8 @@
 	}
 
 	/**
-	 * @see wicket.request.IRequestTargetMounter#mount(java.lang.String,
-	 *      wicket.request.target.coding.IRequestTargetUrlCodingStrategy)
+	 * @see org.apache.wicket.request.IRequestTargetMounter#mount(java.lang.String,
+	 *      org.apache.wicket.request.target.coding.IRequestTargetUrlCodingStrategy)
 	 */
 	public final void mount(String path, IRequestTargetUrlCodingStrategy encoder)
 	{
@@ -415,7 +415,7 @@
 	}
 
 	/**
-	 * @see wicket.request.IRequestCodingStrategy#pathForTarget(wicket.IRequestTarget)
+	 * @see org.apache.wicket.request.IRequestCodingStrategy#pathForTarget(org.apache.wicket.IRequestTarget)
 	 */
 	public final CharSequence pathForTarget(IRequestTarget requestTarget)
 	{
@@ -429,7 +429,7 @@
 	}
 
 	/**
-	 * @see wicket.request.IRequestCodingStrategy#targetForRequest(wicket.request.RequestParameters)
+	 * @see org.apache.wicket.request.IRequestCodingStrategy#targetForRequest(org.apache.wicket.request.RequestParameters)
 	 */
 	public final IRequestTarget targetForRequest(RequestParameters requestParameters)
 	{
@@ -439,7 +439,7 @@
 	}
 
 	/**
-	 * @see wicket.request.IRequestCodingStrategy#unmount(java.lang.String)
+	 * @see org.apache.wicket.request.IRequestCodingStrategy#unmount(java.lang.String)
 	 */
 	public final void unmount(String path)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/request/urlcompressing/UrlCompressingWebCodingStrategy.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/request/urlcompressing/UrlCompressingWebCodingStrategy.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/request/urlcompressing/UrlCompressingWebCodingStrategy.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/request/urlcompressing/UrlCompressingWebCodingStrategy.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/request/urlcompressing/UrlCompressingWebCodingStrategy.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/request/urlcompressing/UrlCompressingWebCodingStrategy.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/request/urlcompressing/UrlCompressingWebCodingStrategy.java Tue Apr 10 11:15:14 2007
@@ -14,25 +14,25 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.protocol.http.request.urlcompressing;
+package org.apache.wicket.protocol.http.request.urlcompressing;
 
-import wicket.Component;
-import wicket.IPageMap;
-import wicket.IRedirectListener;
-import wicket.Page;
-import wicket.RequestCycle;
-import wicket.RequestListenerInterface;
-import wicket.markup.html.WebPage;
-import wicket.protocol.http.request.WebRequestCodingStrategy;
-import wicket.request.RequestParameters;
-import wicket.request.target.component.listener.IListenerInterfaceRequestTarget;
-import wicket.util.string.AppendingStringBuffer;
+import org.apache.wicket.Component;
+import org.apache.wicket.IPageMap;
+import org.apache.wicket.IRedirectListener;
+import org.apache.wicket.Page;
+import org.apache.wicket.RequestCycle;
+import org.apache.wicket.RequestListenerInterface;
+import org.apache.wicket.markup.html.WebPage;
+import org.apache.wicket.protocol.http.request.WebRequestCodingStrategy;
+import org.apache.wicket.request.RequestParameters;
+import org.apache.wicket.request.target.component.listener.IListenerInterfaceRequestTarget;
+import org.apache.wicket.util.string.AppendingStringBuffer;
 
 
 /**
  * Use this CodingStategy with the
  * {@link WebURLCompressingTargetResolverStrategy} to minimize the
- * wicket:interface urls. The component path and the interface name will be
+ * org.apache.wicket:interface urls. The component path and the interface name will be
  * removed from the url and only an uid will be inserted into the url.
  * 
  * Use it like this:

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/request/urlcompressing/UrlCompressingWebRequestProcessor.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/request/urlcompressing/UrlCompressingWebRequestProcessor.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/request/urlcompressing/UrlCompressingWebRequestProcessor.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/request/urlcompressing/UrlCompressingWebRequestProcessor.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/request/urlcompressing/UrlCompressingWebRequestProcessor.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/request/urlcompressing/UrlCompressingWebRequestProcessor.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/request/urlcompressing/UrlCompressingWebRequestProcessor.java Tue Apr 10 11:15:14 2007
@@ -14,28 +14,28 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.protocol.http.request.urlcompressing;
+package org.apache.wicket.protocol.http.request.urlcompressing;
 
-import wicket.Application;
-import wicket.Component;
-import wicket.IRedirectListener;
-import wicket.IRequestTarget;
-import wicket.Page;
-import wicket.RequestCycle;
-import wicket.RequestListenerInterface;
-import wicket.WicketRuntimeException;
-import wicket.authorization.UnauthorizedActionException;
-import wicket.markup.html.INewBrowserWindowListener;
-import wicket.markup.html.WebPage;
-import wicket.protocol.http.WebRequestCycleProcessor;
-import wicket.protocol.http.request.urlcompressing.UrlCompressor.ComponentAndInterface;
-import wicket.request.IRequestCodingStrategy;
-import wicket.request.RequestParameters;
-import wicket.request.target.component.listener.RedirectPageRequestTarget;
-import wicket.util.string.Strings;
+import org.apache.wicket.Application;
+import org.apache.wicket.Component;
+import org.apache.wicket.IRedirectListener;
+import org.apache.wicket.IRequestTarget;
+import org.apache.wicket.Page;
+import org.apache.wicket.RequestCycle;
+import org.apache.wicket.RequestListenerInterface;
+import org.apache.wicket.WicketRuntimeException;
+import org.apache.wicket.authorization.UnauthorizedActionException;
+import org.apache.wicket.markup.html.INewBrowserWindowListener;
+import org.apache.wicket.markup.html.WebPage;
+import org.apache.wicket.protocol.http.WebRequestCycleProcessor;
+import org.apache.wicket.protocol.http.request.urlcompressing.UrlCompressor.ComponentAndInterface;
+import org.apache.wicket.request.IRequestCodingStrategy;
+import org.apache.wicket.request.RequestParameters;
+import org.apache.wicket.request.target.component.listener.RedirectPageRequestTarget;
+import org.apache.wicket.util.string.Strings;
 
 /**
- * Use this processor to minimize the wicket:interface urls. The component path
+ * Use this processor to minimize the org.apache.wicket:interface urls. The component path
  * and the interface name will be removed from the url and only an uid will be
  * inserted into the url.
  * 
@@ -57,7 +57,7 @@
 	}
 
 	/**
-	 * @see wicket.protocol.http.WebRequestCycleProcessor#newRequestCodingStrategy()
+	 * @see org.apache.wicket.protocol.http.WebRequestCycleProcessor#newRequestCodingStrategy()
 	 */
 	protected IRequestCodingStrategy newRequestCodingStrategy()
 	{
@@ -65,9 +65,9 @@
 	}
 
 	/**
-	 * @see wicket.request.AbstractRequestCycleProcessor#resolveListenerInterfaceTarget(wicket.RequestCycle,
-	 *      wicket.Page, java.lang.String, java.lang.String,
-	 *      wicket.request.RequestParameters)
+	 * @see org.apache.wicket.request.AbstractRequestCycleProcessor#resolveListenerInterfaceTarget(org.apache.wicket.RequestCycle,
+	 *      org.apache.wicket.Page, java.lang.String, java.lang.String,
+	 *      org.apache.wicket.request.RequestParameters)
 	 */
 	protected IRequestTarget resolveListenerInterfaceTarget(final RequestCycle requestCycle,
 			final Page page, final String componentPath, String interfaceName,

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/request/urlcompressing/UrlCompressor.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/request/urlcompressing/UrlCompressor.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/request/urlcompressing/UrlCompressor.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/request/urlcompressing/UrlCompressor.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/request/urlcompressing/UrlCompressor.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/request/urlcompressing/UrlCompressor.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/request/urlcompressing/UrlCompressor.java Tue Apr 10 11:15:14 2007
@@ -14,17 +14,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.protocol.http.request.urlcompressing;
+package org.apache.wicket.protocol.http.request.urlcompressing;
 
 import java.io.IOException;
 import java.lang.ref.ReferenceQueue;
 import java.lang.ref.WeakReference;
 import java.util.Iterator;
 
-import wicket.Component;
-import wicket.IClusterable;
-import wicket.util.collections.IntHashMap;
-import wicket.util.collections.IntHashMap.Entry;
+import org.apache.wicket.Component;
+import org.apache.wicket.IClusterable;
+import org.apache.wicket.util.collections.IntHashMap;
+import org.apache.wicket.util.collections.IntHashMap.Entry;
+
 
 /**
  * This class generates UID for Component/Interface combinations when used in

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/servlet/AbortWithHttpStatusException.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/servlet/AbortWithHttpStatusException.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/servlet/AbortWithHttpStatusException.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/servlet/AbortWithHttpStatusException.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/servlet/AbortWithHttpStatusException.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/servlet/AbortWithHttpStatusException.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/servlet/AbortWithHttpStatusException.java Tue Apr 10 11:15:14 2007
@@ -14,15 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.protocol.http.servlet;
+package org.apache.wicket.protocol.http.servlet;
 
 import javax.servlet.http.HttpServletResponse;
 
-import wicket.AbortException;
-import wicket.RequestCycle;
-import wicket.Response;
-import wicket.protocol.http.WebResponse;
-import wicket.request.target.basic.EmptyRequestTarget;
+import org.apache.wicket.AbortException;
+import org.apache.wicket.RequestCycle;
+import org.apache.wicket.Response;
+import org.apache.wicket.protocol.http.WebResponse;
+import org.apache.wicket.request.target.basic.EmptyRequestTarget;
+
 
 /**
  * Causes Wicket to abort processing and set the specified HTTP status code. An
@@ -68,7 +69,7 @@
 			if (!(r instanceof WebResponse))
 			{
 				throw new IllegalStateException(
-						"This exception can only be thrown when wicket is processing an http request");
+						"This exception can only be thrown when org.apache.wicket is processing an http request");
 			}
 
 			WebResponse wr = (WebResponse)r;

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/servlet/AbortWithWebErrorCodeException.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/servlet/AbortWithWebErrorCodeException.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/servlet/AbortWithWebErrorCodeException.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/servlet/AbortWithWebErrorCodeException.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/servlet/AbortWithWebErrorCodeException.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/servlet/AbortWithWebErrorCodeException.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/servlet/AbortWithWebErrorCodeException.java Tue Apr 10 11:15:14 2007
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.protocol.http.servlet;
+package org.apache.wicket.protocol.http.servlet;
 
-import wicket.AbortException;
-import wicket.RequestCycle;
-import wicket.protocol.http.request.WebErrorCodeResponseTarget;
+import org.apache.wicket.AbortException;
+import org.apache.wicket.RequestCycle;
+import org.apache.wicket.protocol.http.request.WebErrorCodeResponseTarget;
 
 /**
  * Causes Wicket to abort processing and set the specified HTTP error code, with

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/servlet/MultipartServletWebRequest.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/servlet/MultipartServletWebRequest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/servlet/MultipartServletWebRequest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/servlet/MultipartServletWebRequest.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/servlet/MultipartServletWebRequest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/servlet/MultipartServletWebRequest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/servlet/MultipartServletWebRequest.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.protocol.http.servlet;
+package org.apache.wicket.protocol.http.servlet;
 
 import java.io.IOException;
 import java.io.InputStream;
@@ -25,15 +25,16 @@
 
 import javax.servlet.http.HttpServletRequest;
 
-import wicket.WicketRuntimeException;
-import wicket.protocol.http.IMultipartWebRequest;
-import wicket.util.lang.Bytes;
-import wicket.util.upload.DiskFileItemFactory;
-import wicket.util.upload.FileItem;
-import wicket.util.upload.FileUploadException;
-import wicket.util.upload.ServletFileUpload;
-import wicket.util.upload.ServletRequestContext;
-import wicket.util.value.ValueMap;
+import org.apache.wicket.WicketRuntimeException;
+import org.apache.wicket.protocol.http.IMultipartWebRequest;
+import org.apache.wicket.util.lang.Bytes;
+import org.apache.wicket.util.upload.DiskFileItemFactory;
+import org.apache.wicket.util.upload.FileItem;
+import org.apache.wicket.util.upload.FileUploadException;
+import org.apache.wicket.util.upload.ServletFileUpload;
+import org.apache.wicket.util.upload.ServletRequestContext;
+import org.apache.wicket.util.value.ValueMap;
+
 
 /**
  * Servlet specific WebRequest subclass for multipart content uploads.
@@ -213,7 +214,7 @@
 	}
 
 	/**
-	 * @see wicket.protocol.http.WebRequest#getParameter(java.lang.String)
+	 * @see org.apache.wicket.protocol.http.WebRequest#getParameter(java.lang.String)
 	 */
 	public String getParameter(final String key)
 	{
@@ -222,7 +223,7 @@
 	}
 
 	/**
-	 * @see wicket.protocol.http.WebRequest#getParameterMap()
+	 * @see org.apache.wicket.protocol.http.WebRequest#getParameterMap()
 	 */
 	public Map getParameterMap()
 	{
@@ -230,7 +231,7 @@
 	}
 
 	/**
-	 * @see wicket.protocol.http.WebRequest#getParameters(java.lang.String)
+	 * @see org.apache.wicket.protocol.http.WebRequest#getParameters(java.lang.String)
 	 */
 	public String[] getParameters(final String key)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/servlet/ServletWebRequest.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/servlet/ServletWebRequest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/servlet/ServletWebRequest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/servlet/ServletWebRequest.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/servlet/ServletWebRequest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/servlet/ServletWebRequest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/servlet/ServletWebRequest.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.protocol.http.servlet;
+package org.apache.wicket.protocol.http.servlet;
 
 import java.util.HashMap;
 import java.util.Locale;
@@ -24,17 +24,17 @@
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.Application;
+import org.apache.wicket.IRedirectListener;
+import org.apache.wicket.RequestListenerInterface;
+import org.apache.wicket.WicketRuntimeException;
+import org.apache.wicket.protocol.http.WebApplication;
+import org.apache.wicket.protocol.http.WebRequest;
+import org.apache.wicket.util.lang.Bytes;
+import org.apache.wicket.util.string.StringValueConversionException;
+import org.apache.wicket.util.string.Strings;
+import org.apache.wicket.util.upload.FileUploadException;
 
-import wicket.Application;
-import wicket.IRedirectListener;
-import wicket.RequestListenerInterface;
-import wicket.WicketRuntimeException;
-import wicket.protocol.http.WebApplication;
-import wicket.protocol.http.WebRequest;
-import wicket.util.lang.Bytes;
-import wicket.util.string.StringValueConversionException;
-import wicket.util.string.Strings;
-import wicket.util.upload.FileUploadException;
 
 /**
  * A Servlet specific WebRequest implementation wrapping a HttpServletRequest
@@ -196,7 +196,7 @@
 	/**
 	 * This will return true if the header "Wicket-Ajax" is set.
 	 * 
-	 * @see wicket.protocol.http.WebRequest#isAjax()
+	 * @see org.apache.wicket.protocol.http.WebRequest#isAjax()
 	 */
 	// TODO matej? should we have a simple way of supporting other ajax things?
 	// or should they just set that same header??
@@ -222,14 +222,14 @@
 	}
 
 	/**
-	 * This method by default calls isAjax(), wicket ajax request do have an
+	 * This method by default calls isAjax(), org.apache.wicket ajax request do have an
 	 * header set. And for all the ajax request the versioning should be merged
 	 * with the previous one. And when it sees that the current request is a
 	 * redirect to page request the version will also be merged with the
 	 * previous one because refresh in the browser or redirects to a page
 	 * shouldn't generate a new version.
 	 * 
-	 * @see wicket.Request#mergeVersion()
+	 * @see org.apache.wicket.Request#mergeVersion()
 	 */
 	public boolean mergeVersion()
 	{
@@ -238,7 +238,7 @@
 	}
 
 	/**
-	 * @see wicket.protocol.http.WebRequest#newMultipartWebRequest(wicket.util.lang.Bytes)
+	 * @see org.apache.wicket.protocol.http.WebRequest#newMultipartWebRequest(org.apache.wicket.util.lang.Bytes)
 	 */
 	public WebRequest newMultipartWebRequest(Bytes maxsize)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/servlet/WicketSessionFilter.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/servlet/WicketSessionFilter.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/servlet/WicketSessionFilter.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/servlet/WicketSessionFilter.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/servlet/WicketSessionFilter.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/protocol/http/servlet/WicketSessionFilter.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/protocol/http/servlet/WicketSessionFilter.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.protocol.http.servlet;
+package org.apache.wicket.protocol.http.servlet;
 
 import java.io.IOException;
 
@@ -29,13 +29,13 @@
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.Session;
 
-import wicket.Session;
 
 /**
  * <p>
  * This filter can be used to make the Wicket
- * {@link wicket.protocol.http.WebSession} instances available to non-wicket
+ * {@link org.apache.wicket.protocol.http.WebSession} instances available to non-org.apache.wicket
  * servlets.
  * </p>
  * <p>
@@ -47,7 +47,7 @@
  * <pre>
  *    &lt;filter&gt;
  *      &lt;filter-name&gt;WicketSessionFilter&lt;/filter-name&gt;
- *      &lt;filter-class&gt;wicket.protocol.http.servlet.WicketSessionFilter&lt;/filter-class&gt;
+ *      &lt;filter-class&gt;org.apache.wicket.protocol.http.servlet.WicketSessionFilter&lt;/filter-class&gt;
  *      &lt;init-param&gt;
  *        &lt;param-name&gt;servletPath&lt;/param-name&gt;
  *        &lt;param-value&gt;sessiontest&lt;/param-value&gt;
@@ -61,7 +61,7 @@
  *   
  *    &lt;servlet&gt;
  *      &lt;servlet-name&gt;SessionApplication&lt;/servlet-name&gt;
- *      &lt;servlet-class&gt;wicket.protocol.http.WicketServlet&lt;/servlet-class&gt;
+ *      &lt;servlet-class&gt;org.apache.wicket.protocol.http.WicketServlet&lt;/servlet-class&gt;
  *      &lt;init-param&gt;
  *        &lt;param-name&gt;applicationClassName&lt;/param-name&gt;
  *        &lt;param-value&gt;session.SessionApplication&lt;/param-value&gt;
@@ -89,7 +89,7 @@
  * After that, you can get to the Wicket session in the usual fashion:
  * 
  * <pre>
- * wicket.Session wicketSession = wicket.Session.get();
+ * org.apache.wicket.Session wicketSession = org.apache.wicket.Session.get();
  * </pre>
  * 
  * </p>
@@ -138,7 +138,7 @@
 			log.debug("servlet path set to " + servletPath);
 		}
 
-		sessionKey = "wicket:" + servletPath + ":" + Session.SESSION_ATTRIBUTE_NAME;
+		sessionKey = "org.apache.wicket:" + servletPath + ":" + Session.SESSION_ATTRIBUTE_NAME;
 
 		if (log.isDebugEnabled())
 		{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/request/AbstractRequestCycleProcessor.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/request/AbstractRequestCycleProcessor.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/request/AbstractRequestCycleProcessor.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/request/AbstractRequestCycleProcessor.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/request/AbstractRequestCycleProcessor.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/request/AbstractRequestCycleProcessor.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/request/AbstractRequestCycleProcessor.java Tue Apr 10 11:15:14 2007
@@ -14,38 +14,39 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.request;
+package org.apache.wicket.request;
 
 import javax.servlet.http.HttpServletResponse;
 
-import wicket.Application;
-import wicket.Component;
-import wicket.IRedirectListener;
-import wicket.IRequestTarget;
-import wicket.Page;
-import wicket.PageParameters;
-import wicket.RequestCycle;
-import wicket.RequestListenerInterface;
-import wicket.RestartResponseAtInterceptPageException;
-import wicket.RestartResponseException;
-import wicket.Session;
-import wicket.WicketRuntimeException;
-import wicket.authorization.AuthorizationException;
-import wicket.authorization.UnauthorizedActionException;
-import wicket.markup.MarkupException;
-import wicket.markup.html.INewBrowserWindowListener;
-import wicket.markup.html.pages.ExceptionErrorPage;
-import wicket.protocol.http.PageExpiredException;
-import wicket.protocol.http.request.WebErrorCodeResponseTarget;
-import wicket.protocol.http.request.WebExternalResourceRequestTarget;
-import wicket.request.target.IEventProcessor;
-import wicket.request.target.component.BookmarkableListenerInterfaceRequestTarget;
-import wicket.request.target.component.BookmarkablePageRequestTarget;
-import wicket.request.target.component.PageRequestTarget;
-import wicket.request.target.component.listener.RedirectPageRequestTarget;
-import wicket.request.target.resource.SharedResourceRequestTarget;
-import wicket.settings.IExceptionSettings;
-import wicket.util.string.Strings;
+import org.apache.wicket.Application;
+import org.apache.wicket.Component;
+import org.apache.wicket.IRedirectListener;
+import org.apache.wicket.IRequestTarget;
+import org.apache.wicket.Page;
+import org.apache.wicket.PageParameters;
+import org.apache.wicket.RequestCycle;
+import org.apache.wicket.RequestListenerInterface;
+import org.apache.wicket.RestartResponseAtInterceptPageException;
+import org.apache.wicket.RestartResponseException;
+import org.apache.wicket.Session;
+import org.apache.wicket.WicketRuntimeException;
+import org.apache.wicket.authorization.AuthorizationException;
+import org.apache.wicket.authorization.UnauthorizedActionException;
+import org.apache.wicket.markup.MarkupException;
+import org.apache.wicket.markup.html.INewBrowserWindowListener;
+import org.apache.wicket.markup.html.pages.ExceptionErrorPage;
+import org.apache.wicket.protocol.http.PageExpiredException;
+import org.apache.wicket.protocol.http.request.WebErrorCodeResponseTarget;
+import org.apache.wicket.protocol.http.request.WebExternalResourceRequestTarget;
+import org.apache.wicket.request.target.IEventProcessor;
+import org.apache.wicket.request.target.component.BookmarkableListenerInterfaceRequestTarget;
+import org.apache.wicket.request.target.component.BookmarkablePageRequestTarget;
+import org.apache.wicket.request.target.component.PageRequestTarget;
+import org.apache.wicket.request.target.component.listener.RedirectPageRequestTarget;
+import org.apache.wicket.request.target.resource.SharedResourceRequestTarget;
+import org.apache.wicket.settings.IExceptionSettings;
+import org.apache.wicket.util.string.Strings;
+
 
 /**
  * Default abstract implementation of {@link IRequestCycleProcessor}.
@@ -65,7 +66,7 @@
 	}
 
 	/**
-	 * @see wicket.request.IRequestCycleProcessor#getRequestCodingStrategy()
+	 * @see org.apache.wicket.request.IRequestCycleProcessor#getRequestCodingStrategy()
 	 */
 	public IRequestCodingStrategy getRequestCodingStrategy()
 	{
@@ -77,7 +78,7 @@
 	}
 
 	/**
-	 * @see wicket.request.IRequestCycleProcessor#processEvents(wicket.RequestCycle)
+	 * @see org.apache.wicket.request.IRequestCycleProcessor#processEvents(org.apache.wicket.RequestCycle)
 	 */
 	public void processEvents(RequestCycle requestCycle)
 	{
@@ -91,7 +92,7 @@
 	}
 
 	/**
-	 * @see wicket.request.IRequestCycleProcessor#respond(wicket.RequestCycle)
+	 * @see org.apache.wicket.request.IRequestCycleProcessor#respond(org.apache.wicket.RequestCycle)
 	 */
 	public void respond(RequestCycle requestCycle)
 	{
@@ -104,8 +105,8 @@
 	}
 
 	/**
-	 * @see wicket.request.IRequestCycleProcessor#respond(java.lang.RuntimeException,
-	 *      wicket.RequestCycle)
+	 * @see org.apache.wicket.request.IRequestCycleProcessor#respond(java.lang.RuntimeException,
+	 *      org.apache.wicket.RequestCycle)
 	 */
 	public void respond(RuntimeException e, RequestCycle requestCycle)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/request/ClientInfo.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/request/ClientInfo.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/request/ClientInfo.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/request/ClientInfo.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/request/ClientInfo.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/request/ClientInfo.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/request/ClientInfo.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.request;
+package org.apache.wicket.request;
 
-import wicket.IClusterable;
+import org.apache.wicket.IClusterable;
 
 /**
  * Encapsulates information about the request cycle agents' capabilities.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/request/IRequestCodingStrategy.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/request/IRequestCodingStrategy.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/request/IRequestCodingStrategy.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/request/IRequestCodingStrategy.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/request/IRequestCodingStrategy.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/request/IRequestCodingStrategy.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/request/IRequestCodingStrategy.java Tue Apr 10 11:15:14 2007
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.request;
+package org.apache.wicket.request;
 
-import wicket.IRequestTarget;
-import wicket.Request;
-import wicket.RequestCycle;
+import org.apache.wicket.IRequestTarget;
+import org.apache.wicket.Request;
+import org.apache.wicket.RequestCycle;
 
 /**
  * Implementations of this interface are responsible for digesting the incoming
  * request and creating a suitable {@link wicket.request.RequestParameters} object
  * for it, as well as creating url representations for request targets.
  * 
  * @author Eelco Hillenius
@@ -14,15 +14,15 @@
 /**
  * Implementations of this interface are responsible for digesting the incoming
- * request and creating a suitable {@link wicket.request.RequestParameters} object
+ * request and creating a suitable {@link org.apache.wicket.request.RequestParameters} object
  * for it, as well as creating url representations for request targets.
  * 